@@ -267,3 +267,22 @@ def copy_dir(old_dir: str, new_dir: str, overwrite=True) -> None:
     if overwrite and os.path.isdir(new_dir):
         shutil.rmtree(new_dir)
     shutil.copytree(old_dir, new_dir)
+
+
+def convert_str_to_bool(bool_str: str) -> None:
+    """
+    The convert_str_to_bool function takes a string and converts it to a boolean.
+        The function is used in the main() function to convert the override value from
+        a string to a boolean.
+
+    :param bool_str:str: Used to Specify the type of data that will be passed into the function.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
+    """
+
+    if bool_str == "True":
+        bool_str = True
+    if bool_str == "False":
+        bool_str = False
+    return bool_str
